# Contributing to PsyNeuLink

Welcome. Thank you for your interest in contributing to PsyNeuLink! Before contributing, please read through our [Contributor's Guide on our documentation website]
(https://princetonuniversity.github.io/PsyNeuLink/ContributorsGuide.html). This contains information about setting up your environment, and the development workflow.

When writing code, please follow our coding conventions, found in the CONVENTIONS.md file.